@@ -7,24 +7,23 @@ from django.test import TestCase, override_settings
 
 
 class MigrationTestCase(TestCase):
-
     @override_settings(MIGRATION_MODULES={})
     def test_for_missing_migrations(self):
         output = io.StringIO()
         options = {
-            'interactive': False,
-            'dry_run': True,
-            'stdout': output,
-            'check_changes': True,
+            "interactive": False,
+            "dry_run": True,
+            "stdout": output,
+            "check_changes": True,
         }
 
         try:
-            call_command('makemigrations', **options)
+            call_command("makemigrations", "djangocms_admin_style", **options)
         except SystemExit as e:
             status_code = str(e)
         else:
             # the "no changes" exit code is 0
-            status_code = '0'
+            status_code = "0"
 
-        if status_code == '1':
-            self.fail('There are missing migrations:\n {}'.format(output.getvalue()))
+        if status_code == "1":
+            self.fail(f"There are missing migrations:\n {output.getvalue()}")
